::: spotify.api.API
    options:
      members:
        - get_tracks_audio_features
        - get_several_tracks_audio_features
        - get_tracks_audio_analysis
::: spotify.models.AudioFeatures
::: spotify.models.AudioAnalysis
::: spotify.models.AudioAnalysisMeta
::: spotify.models.AudioAnalysisTrack
::: spotify.models.AudioAnalysisBar
::: spotify.models.AudioAnalysisBeat
::: spotify.models.AudioAnalysisSection
::: spotify.models.AudioAnalysisSegment
::: spotify.models.AudioAnalysisTatum
